Welcome
=======

Welcome to the documentation for the Python ``dataretrieval`` package.
``dataretrieval`` is a Python alternative to the `USGS R dataRetrieval package`_
and is used to obtain USGS and EPA water quality data, streamflow data, and
metadata directly from webservices (see the
:doc:`data portals documentation </userguide/dataportals>` for additional
details about specific data sources).

.. _USGS R dataRetrieval package: https://github.com/DOI-USGS/dataRetrieval


Table of Contents
-----------------

.. toctree::
   :maxdepth: 1

   meta/installing
   userguide/index
   examples/index
   meta/contributing
   meta/license
   reference/index
